@@ -2,10 +2,10 @@
 Routines for converting PollyXT files to SCC files
 """
 
-from datetime import date, datetime, timedelta
+from datetime import datetime, timedelta
 from pathlib import Path
 from typing import Tuple
-from enum import Enum
+from enum import Enum, IntEnum
 
 from netCDF4 import Dataset
 import numpy as np
@@ -23,6 +23,31 @@ class Wavelength(Enum):
     NM_532 = 532
 
 
+class Atmosphere(IntEnum):
+    """
+    Which atmosphere to use to processing. These are the possible values for `molecular_calc`.
+    """
+
+    AUTOMATIC = 0
+    RADIOSONDE = 1
+    CLOUDNET = 2
+    STANDARD_ATMOSPHERE = 4
+
+    @staticmethod
+    def from_string(x: str):
+        x = x.lower().strip()
+        if x == "automatic":
+            return Atmosphere.AUTOMATIC
+        if x == "radiosonde":
+            return Atmosphere.RADIOSONDE
+        if x == "cloudnet":
+            return Atmosphere.CLOUDNET
+        if x == "standard":
+            return Atmosphere.STANDARD_ATMOSPHERE
+
+        raise ValueError(f"Unknown atmosphere {x}")
+
+
 """When calibration takes place each day, in HH:MM-HH:MM format"""
 CALIBRATION_PERIODS = ["02:31-02:41", "17:31-17:41", "21:31-21:41"]
 
@@ -45,7 +70,10 @@ def calibration_to_datetime(base: datetime, period: str) -> Tuple[datetime, date
 
 
 def create_scc_netcdf(
-    pf: pollyxt.PollyXTFile, output_path: Path, location: Location, use_sounding: bool = True
+    pf: pollyxt.PollyXTFile,
+    output_path: Path,
+    location: Location,
+    atmosphere=Atmosphere.STANDARD_ATMOSPHERE,
 ) -> Tuple[str, Path]:
     """
     Convert a PollyXT netCDF file to a SCC file.
@@ -54,9 +82,12 @@ def create_scc_netcdf(
         pf: An opened PollyXT file. When you create this, you can specify the time period of interest.
         output_path: Where to store the produced netCDF file
         location: Where did this measurement take place
-        use_sounding: Whether this file will be accompanied by a radiosonde file or not. If this is set to True, the
-                      `Sounding_File_Name` attribute will be set to the generated filename (`rs_{MEASUREMENT_ID}.rs`)
-                      and the `Molecular_Calc` variable will be set to 1, otherwise 0.
+        atmosphere: What kind of atmosphere to use.
+
+    Note:
+        If atmosphere is set to Atmosphere.SOUNDING, the `Sounding_File_Name` attribute will be set to
+        `rs_{MEASUREMENT_ID}.rs`, ie the filename of the accompaning radiosonde. This file is *not* created
+        by this function.
 
     Returns:
         A tuple containing  the measurement ID and the output path
@@ -87,7 +118,7 @@ def create_scc_netcdf(
     nc.RawBck_Start_Date = nc.RawData_Start_Date
     nc.RawBck_Start_Time_UT = nc.RawData_Start_Time_UT
     nc.RawBck_Stop_Time_UT = nc.RawData_Stop_Time_UT
-    if use_sounding:
+    if atmosphere == Atmosphere.RADIOSONDE:
         nc.Sounding_File_Name = f"rs_{measurement_id[:-2]}.nc"
     # nc.Overlap_File_Name = 'ov_' + selected_start.strftime('%Y%m%daky%H') + '.nc'
 
@@ -146,10 +177,7 @@ def create_scc_netcdf(
     laser_shots[:] = pf.measurement_shots[:]
     background_low[:] = np.array(location.background_low)
     background_high[:] = np.array(location.background_high)
-    if use_sounding:
-        molecular_calc[:] = 1
-    else:
-        molecular_calc[:] = 0
+    molecular_calc[:] = int(atmosphere)
     pressure_at_lidar_station[:] = location.pressure
     temperature_at_lidar_station[:] = location.temperature
     lr_input[:] = np.array(location.lr_input)
@@ -320,7 +348,7 @@ def convert_pollyxt_file(
     output_path: Path,
     location: Location,
     interval: timedelta,
-    use_sounding=True,
+    atmosphere: Atmosphere,
     should_round=False,
     calibration=True,
     start_time=None,
@@ -341,7 +369,7 @@ def convert_pollyxt_file(
         output_path: Directory to write the SCC files
         location: Geographical information, where the measurement took place
         interval: What interval to use when splitting the PollyXT file (e.g. 1 hour)
-        use_rounding: Whether the generated files will use radiosondes or not.
+        atmosphere: Which atmosphere to use on SCC
         should_round: If true, the interval starts will be rounded down. For example, from 01:02 to 01:00.
         calibration: Set to False to disable generation of calibration files.
         start_hour: Optionally, set when the first file should start. The intervals will start from here. (HH:MM or YYYY-MM-DD_HH:MM format, string)
@@ -386,7 +414,7 @@ def convert_pollyxt_file(
         # Open netCDF file and convert to SCC
         try:
             pf = repo.get_pollyxt_file(interval_start, interval_end)
-            id, path = create_scc_netcdf(pf, output_path, location, use_sounding)
+            id, path = create_scc_netcdf(pf, output_path, location, atmosphere)
 
             yield id, path, pf.start_date, pf.end_date
         except NoMeasurementsInTimePeriod as ex:
